import{u as n}from"./index.d3c08eba.js";import"./outputWidgets.f4ff73cb.js";import{r as s,w as a}from"./runnerData.f9578373.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="1bbf0a6e-8059-4f71-9ca8-b54dc204014d",t._sentryDebugIdIdentifier="sentry-dbid-1bbf0a6e-8059-4f71-9ca8-b54dc204014d")}catch{}})();async function i(t){const e=await fetch(`/_pages/${t}`,{headers:n.authHeaders()});if(e.status==404)return null;if(!e.ok)throw new Error(await e.text());const{form:r}=await e.json();return r?s(r):null}async function c(){const t=await fetch("/_workspace");if(t.status!=200)return a({});const e=await t.json();return a(e)}export{i as f,c as g};
//# sourceMappingURL=api.47f2b83e.js.map
