import{W as s,f as p,S as d}from"./outputWidgets.f4ff73cb.js";import{B as c,b as f}from"./Base.2cf6cca2.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="feea019c-3603-4a7c-9b60-2a2610cd765e",e._sentryDebugIdIdentifier="sentry-dbid-feea019c-3603-4a7c-9b60-2a2610cd765e")}catch{}})();const i=()=>d(f(),["component"]),r=(e,a)=>{let{slots:t,attrs:o}=a;const n=s(s(s({},e),{component:"div"}),o);return p(c,n,t)};r.displayName="ATypographyParagraph";r.inheritAttrs=!1;r.props=i();const b=r;export{b as A};
//# sourceMappingURL=Paragraph.0762ff9a.js.map
