import{C as t,E as d,K as i,a as c,M as l,c as y,P as f,R as g,S as u,b,T as k,U as p,e as w,l as D}from"./toggleHighContrast.6b74fb91.js";import"./outputWidgets.f4ff73cb.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="7ed3eaed-91c9-4c71-896a-5ce181ea96a0",e._sentryDebugIdIdentifier="sentry-dbid-7ed3eaed-91c9-4c71-896a-5ce181ea96a0")}catch{}})();export{t as CancellationTokenSource,d as Emitter,i as KeyCode,c as KeyMod,l as MarkerSeverity,y as MarkerTag,f as Position,g as Range,u as Selection,b as SelectionDirection,k as Token,p as Uri,w as editor,D as languages};
//# sourceMappingURL=editor.main.6a0bc788.js.map
