import{f as o,eI as u,eW as f}from"./outputWidgets.f4ff73cb.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="e23d7e9c-97b4-4168-8a8c-678d4399d0f3",e._sentryDebugIdIdentifier="sentry-dbid-e23d7e9c-97b4-4168-8a8c-678d4399d0f3")}catch{}})();function a(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?Object(arguments[t]):{},r=Object.keys(n);typeof Object.getOwnPropertySymbols=="function"&&(r=r.concat(Object.getOwnPropertySymbols(n).filter(function(d){return Object.getOwnPropertyDescriptor(n,d).enumerable}))),r.forEach(function(d){c(e,d,n[d])})}return e}function c(e,t,n){return t in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}var i=function(t,n){var r=a({},t,n.attrs);return o(u,a({},r,{icon:f}),null)};i.displayName="LoadingOutlined";i.inheritAttrs=!1;const s=i;export{s as L};
//# sourceMappingURL=LoadingOutlined.7dd20886.js.map
