import{ad as c,W as t,S as r,f as p}from"./outputWidgets.f4ff73cb.js";import{B as f,b as l}from"./Base.2cf6cca2.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="1cb04225-87ca-4d86-9e8c-646ecb073f9a",e._sentryDebugIdIdentifier="sentry-dbid-1cb04225-87ca-4d86-9e8c-646ecb073f9a")}catch{}})();const b=()=>t(t({},r(l(),["component"])),{ellipsis:{type:[Boolean,Object],default:void 0}}),o=(e,s)=>{let{slots:a,attrs:d}=s;const{ellipsis:n}=e;c();const i=t(t(t({},e),{ellipsis:n&&typeof n=="object"?r(n,["expandable","rows"]):n,component:"span"}),d);return p(f,i,a)};o.displayName="ATypographyText";o.inheritAttrs=!1;o.props=b();const g=o;export{g as A};
//# sourceMappingURL=Text.b0ae0f80.js.map
