import{O as i}from"./index.d3c08eba.js";import{A as d}from"./Title.8356c432.js";import"./index.1893243b.js";import{A as l}from"./Text.b0ae0f80.js";import{d as u,o as c,b as f,ew as m,f as o,w as a,u as r,as as n}from"./outputWidgets.f4ff73cb.js";import"./fetch.94c8b741.js";import"./pubsub.f8e50115.js";import"./Base.2cf6cca2.js";import"./Link.58a56401.js";import"./Paragraph.0762ff9a.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="be89528d-6761-42a5-a0f9-b18b7b8556dc",e._sentryDebugIdIdentifier="sentry-dbid-be89528d-6761-42a5-a0f9-b18b7b8556dc")}catch{}})();const x=u({__name:"OidcLoginCallback",setup(e){return c(async()=>{await new i().loginCallback()}),(t,s)=>(f(),m("div",null,[o(r(d),null,{default:a(()=>[n("You're authenticated")]),_:1}),o(r(l),null,{default:a(()=>[n(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{x as default};
//# sourceMappingURL=OidcLoginCallback.6f78d015.js.map
