import{F as t}from"./Form.c8ea7c3d.js";import{b3 as r,cn as n}from"./outputWidgets.f4ff73cb.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="220b97b6-fc45-4e4d-a97b-b4cc7493d0cb",e._sentryDebugIdIdentifier="sentry-dbid-220b97b6-fc45-4e4d-a97b-b4cc7493d0cb")}catch{}})();t.useInjectFormItemContext=r;t.ItemRest=n;t.install=function(e){return e.component(t.name,t),e.component(t.Item.name,t.Item),e.component(n.name,n),e};
//# sourceMappingURL=index.971fc0f1.js.map
