import{B as r}from"./BookOutlined.eb157924.js";import{d as c,b as a,c as l,w as o,f,u as d,dl as u,ew as i,as as p,aE as b,bG as y}from"./outputWidgets.f4ff73cb.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="72ed48b7-ad2c-4543-acfc-ccedd59b0ced",t._sentryDebugIdIdentifier="sentry-dbid-72ed48b7-ad2c-4543-acfc-ccedd59b0ced")}catch{}})();const k=c({__name:"DocsButton",props:{path:{}},setup(t){return(e,n)=>{var s;return a(),l(d(y),{class:"docs-button",href:`https://docs.abstra.io/${(s=e.path)!=null?s:""}`,target:"_blank",type:"link",style:{color:"#d14056"},size:"small"},{icon:o(()=>[f(d(r))]),default:o(()=>[e.$slots.default?u(e.$slots,"default",{key:0}):(a(),i(b,{key:1},[p("Docs")],64))]),_:3},8,["href"])}}});export{k as _};
//# sourceMappingURL=DocsButton.vue_vue_type_script_setup_true_lang.273d3e2a.js.map
