import{O as d}from"./index.d3c08eba.js";import{d as i,o as l,b as u,ew as f,f as a,w as o,u as r,as as n}from"./outputWidgets.f4ff73cb.js";import{A as c}from"./Title.8356c432.js";import{A as m}from"./Text.b0ae0f80.js";import"./fetch.94c8b741.js";import"./pubsub.f8e50115.js";import"./Base.2cf6cca2.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="60d214aa-ba89-4169-9640-f949145d1fbd",e._sentryDebugIdIdentifier="sentry-dbid-60d214aa-ba89-4169-9640-f949145d1fbd")}catch{}})();const I=i({__name:"OidcLogoutCallback",setup(e){return l(async()=>{await new d().logoutCallback()}),(t,s)=>(u(),f("div",null,[a(r(c),null,{default:o(()=>[n("You're authenticated")]),_:1}),a(r(m),null,{default:o(()=>[n(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{I as default};
//# sourceMappingURL=OidcLogoutCallback.9fd01b0c.js.map
