import"./outputWidgets.f4ff73cb.js";(function(){try{var x=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(x._sentryDebugIds=x._sentryDebugIds||{},x._sentryDebugIds[e]="c137d2e1-60f3-404f-8618-01134695c6c1",x._sentryDebugIdIdentifier="sentry-dbid-c137d2e1-60f3-404f-8618-01134695c6c1")}catch{}})();const d=()=>"xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx".replace(/[xy]/g,function(x){const e=Math.random()*16|0;return(x=="x"?e:e&3|8).toString(16)});export{d as u};
//# sourceMappingURL=uuid.13a8210c.js.map
