import{d as o,b as s,ew as a,e as d,dl as l,eA as r,x as f}from"./outputWidgets.f4ff73cb.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="4eeacb2a-f22f-4993-99dd-0f343ec2998d",e._sentryDebugIdIdentifier="sentry-dbid-4eeacb2a-f22f-4993-99dd-0f343ec2998d")}catch{}})();const c={class:"content-layout"},_=o({__name:"ContentLayout",props:{fullWidth:{type:Boolean}},setup(e){return(t,n)=>(s(),a("div",c,[d("div",{class:r(["centered-layout",{"full-width":t.fullWidth}])},[l(t.$slots,"default",{},void 0,!0)],2)]))}});const i=f(_,[["__scopeId","data-v-00ef87a4"]]);export{i as C};
//# sourceMappingURL=ContentLayout.52723b88.js.map
