.container[data-v-420f3514]{display:flex;justify-content:center;align-items:center;width:100%;height:100%}.form-card[data-v-420f3514]{cursor:pointer}.form-card[data-v-420f3514]:hover{box-shadow:0 0 10px #0000001a}
