import{_ as I}from"./logo.084e5d7c.js";import{x,b as r,ew as p,eC as w,eD as C,e as l,d as k,eK as N,a as D,u as e,c,bh as L,w as t,f as a,as as d,eH as f,bG as m,cE as S,cA as $,eN as E,eF as V,f9 as z,aE as b,ey as F,dl as R}from"./outputWidgets.f4ff73cb.js";import{b as h,c as T}from"./router.579c91e6.js";import{a as H}from"./asyncComputed.1c2e733f.js";import{F as P}from"./PhSignOut.vue.21b85b35.js";import{A as j}from"./Text.b0ae0f80.js";import{A as q}from"./index.db4b3bef.js";import{B as G,A as K,b as M}from"./index.772c2560.js";import{B as O}from"./BookOutlined.eb157924.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[s]="6a98cd46-e2f0-4936-8852-fadddf4117a0",o._sentryDebugIdIdentifier="sentry-dbid-6a98cd46-e2f0-4936-8852-fadddf4117a0")}catch{}})();const U={},v=o=>(w("data-v-46e041c1"),o=o(),C(),o),J={class:"logo"},Q=v(()=>l("img",{class:"logo-img",src:I,alt:"Abstra cloud logo"},null,-1)),W=v(()=>l("span",null,"Abstra",-1)),X=[Q,W];function Y(o,s){return r(),p("div",J,X)}const Z=x(U,[["render",Y],["__scopeId","data-v-46e041c1"]]),ee={style:{display:"flex","flex-direction":"column",gap:"10px"}},te={style:{display:"flex",gap:"5px"}},oe=k({__name:"LoginBlock",setup(o){function s(g){const y=g.split("@")[0];return E.exports.kebabCase(y).toUpperCase().split("-").slice(0,2).map(u=>u[0]).join("")}const i=N(),{result:n,loading:_,refetch:A}=H(async()=>h.getAuthor());function B(){h.removeAuthor(),T.shutdown(),A(),i.push({name:"login"})}return(g,y)=>{const u=D("router-link");return e(_)?(r(),c(e(L),{key:0})):e(n)?(r(),c(e($),{key:1,placement:"bottomRight"},{content:t(()=>[l("div",ee,[a(e(j),{size:"small",type:"secondary"},{default:t(()=>[d(f(e(n).claims.email),1)]),_:1}),a(e(m),{type:"text",onClick:B},{default:t(()=>[l("div",te,[a(e(P),{size:"20"}),d(" Logout ")])]),_:1})])]),default:t(()=>[a(e(S),{align:"center",style:{cursor:"pointer"}},{default:t(()=>[a(e(q),{shape:"square"},{default:t(()=>[d(f(s(e(n).claims.email)),1)]),_:1})]),_:1})]),_:1})):(r(),c(e(m),{key:2},{default:t(()=>[a(u,{to:"/login"},{default:t(()=>[d("Login")]),_:1})]),_:1}))}}}),ae={class:"extra"},se=k({__name:"Navbar",props:{breadcrumb:{}},setup(o){return(s,i)=>(r(),c(e(M),{style:{padding:"5px 25px",border:"1px solid #f0f0f0"}},{subTitle:t(()=>[s.breadcrumb?(r(),c(e(G),{key:0,style:{margin:"0px 50px"}},{default:t(()=>[(r(!0),p(b,null,V(s.breadcrumb,(n,_)=>(r(),c(e(K),{key:_},{default:t(()=>[a(e(z),{to:n.path},{default:t(()=>[d(f(n.label),1)]),_:2},1032,["to"])]),_:2},1024))),128))]),_:1})):F("",!0)]),title:t(()=>[a(Z)]),extra:t(()=>[l("div",ae,[a(e(m),{class:"docs-button",href:"https://docs.abstra.io/",target:"_blank",type:"link",style:{color:"#d14056"},size:"small"},{icon:t(()=>[a(e(O))]),default:t(()=>[s.$slots.default?R(s.$slots,"default",{key:0},void 0,!0):(r(),p(b,{key:1},[d("Docs")],64))]),_:3}),a(oe)])]),_:3}))}});const fe=x(se,[["__scopeId","data-v-31e2a422"]]);export{fe as N};
//# sourceMappingURL=Navbar.8098dad5.js.map
