.inner-content[data-v-f770b2d7]{display:flex;justify-content:center;align-items:center;flex-direction:column;flex-grow:1;padding-bottom:48px}.message[data-v-f770b2d7]{width:400px;text-align:center;font-size:16px;margin-bottom:40px}
