import{a as e,B as d}from"./Base.2cf6cca2.js";import{A as o}from"./Link.58a56401.js";import{A as r}from"./Paragraph.0762ff9a.js";import{A as a}from"./Text.b0ae0f80.js";import{A as i}from"./Title.8356c432.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[t]="f43cc8b1-0757-4e88-9b0d-ecded7991b1b",n._sentryDebugIdIdentifier="sentry-dbid-f43cc8b1-0757-4e88-9b0d-ecded7991b1b")}catch{}})();e.Text=a;e.Title=i;e.Paragraph=r;e.Link=o;e.Base=d;e.install=function(n){return n.component(e.name,e),n.component(e.Text.displayName,a),n.component(e.Title.displayName,i),n.component(e.Paragraph.displayName,r),n.component(e.Link.displayName,o),n};
//# sourceMappingURL=index.1893243b.js.map
