import{C as b}from"./ContentLayout.52723b88.js";import{A as f,K as l,_ as g,E as k}from"./TableView.vue_vue_type_script_setup_true_lang.8b0e93dc.js";import{d as _,r as w,b as n,c as s,w as m,L as h,f as i,u as e,ey as c}from"./outputWidgets.f4ff73cb.js";import{l as T}from"./fetch.94c8b741.js";import{A as d,T as v}from"./TabPane.12230f18.js";import"./vuedraggable.umd.98bc57eb.js";import"./workspaces.b1acd1b5.js";import"./runnerData.f9578373.js";import"./url.f4aa4fed.js";import"./record.06ee4427.js";import"./pubsub.f8e50115.js";import"./asyncComputed.1c2e733f.js";import"./scripts.257e5be3.js";import"./envVars.092fda86.js";import"./api.d23d8696.js";import"./metadata.c0f81356.js";import"./PhCheckCircle.vue.400689d9.js";import"./PhScroll.vue.3415beb3.js";import"./PhWebhooksLogo.vue.ca0fc489.js";import"./ant-design.b167c820.js";import"./index.81bff51e.js";import"./Modal.fb9d97fb.js";import"./Text.b0ae0f80.js";import"./Base.2cf6cca2.js";import"./index.38a388d2.js";import"./index.72e9756f.js";import"./index.feda5b51.js";import"./Paragraph.0762ff9a.js";import"./index.1893243b.js";import"./Link.58a56401.js";import"./Title.8356c432.js";import"./index.79c263e0.js";import"./CollapsePanel.5f9312a1.js";import"./index.cead1e00.js";import"./index.5920a48d.js";import"./isNumeric.75337b1e.js";import"./PhArrowCounterClockwise.vue.01cffaf3.js";import"./Card.c86b7818.js";import"./LoadingOutlined.7dd20886.js";import"./index.971fc0f1.js";import"./Form.c8ea7c3d.js";import"./hasIn.c05f2ad3.js";import"./string.08374cff.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[t]="4869c848-fd12-4e19-b97c-2eda24a9682e",o._sentryDebugIdIdentifier="sentry-dbid-4869c848-fd12-4e19-b97c-2eda24a9682e")}catch{}})();class S{constructor(t=T){this.fetch=t}async fork(t){return(await this.fetch("/_editor/api/stage_runs/fork",{method:"POST",body:JSON.stringify({stage_run_id:t}),headers:{"Content-Type":"application/json"}})).json()}async retry(t){return(await this.fetch("/_editor/api/stage_runs/retry",{method:"POST",body:JSON.stringify({stage_run_id:t}),headers:{"Content-Type":"application/json"}})).json()}}const ft=_({__name:"WorkflowThreads",setup(o){const t=new k,r=new S,u=new h(f,"kanban-selected-stages"),a=w("kanban");return(C,p)=>(n(),s(b,{"full-width":""},{default:m(()=>[i(e(v),{activeKey:a.value,"onUpdate:activeKey":p[0]||(p[0]=y=>a.value=y)},{default:m(()=>[i(e(d),{key:"kanban",tab:"Kanban View"}),i(e(d),{key:"table",tab:"Table View"})]),_:1},8,["activeKey"]),a.value==="kanban"?(n(),s(l,{key:0,"kanban-repository":e(t),"kanban-stages-storage":e(u),"stage-run-repository":e(r)},null,8,["kanban-repository","kanban-stages-storage","stage-run-repository"])):c("",!0),a.value==="table"?(n(),s(g,{key:1,"kanban-repository":e(t)},null,8,["kanban-repository"])):c("",!0)]),_:1}))}});export{ft as default};
//# sourceMappingURL=WorkflowThreads.6b593bf4.js.map
