import{x as o,a as r,b as i,c as d,j as c,T as p,k as f,P as _,C as u,M as l,s as g,l as s,m,n as y,p as v,q as w}from"./outputWidgets.f4ff73cb.js";import{s as b,a}from"./index.d3c08eba.js";import"./fetch.94c8b741.js";import"./pubsub.f8e50115.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="c8d2fb08-ad3e-4334-84a1-dfd5fac1d76d",e._sentryDebugIdIdentifier="sentry-dbid-c8d2fb08-ad3e-4334-84a1-dfd5fac1d76d")}catch{}})();const h={};function I(e,t){const n=r("router-view");return i(),d(n,{style:{height:"100vh",width:"100%"}})}const k=o(h,[["render",I]]);class x{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await b();const e=c({render:()=>m(k)});p.init(),f(e,a),x.init(),e.use(a),e.use(_),e.mount("#app"),e.component("VSelect",u),e.component("Markdown",l),e.component("Message",g),s(e,y),s(e,v),s(e,w)})();
//# sourceMappingURL=player.6756adbe.js.map
