import{u as d}from"./index.d3c08eba.js";import{d as f,r as l,b as r,ew as _,f as n,w as u,u as t,c as p,ey as m,L as y,x as k}from"./outputWidgets.f4ff73cb.js";import{K as g,_ as v,A as w,P as T}from"./TableView.vue_vue_type_script_setup_true_lang.8b0e93dc.js";import{A as c,T as h}from"./TabPane.12230f18.js";import"./Card.c86b7818.js";import"./fetch.94c8b741.js";import"./pubsub.f8e50115.js";import"./vuedraggable.umd.98bc57eb.js";import"./workspaces.b1acd1b5.js";import"./runnerData.f9578373.js";import"./url.f4aa4fed.js";import"./record.06ee4427.js";import"./asyncComputed.1c2e733f.js";import"./scripts.257e5be3.js";import"./envVars.092fda86.js";import"./api.d23d8696.js";import"./metadata.c0f81356.js";import"./PhCheckCircle.vue.400689d9.js";import"./PhScroll.vue.3415beb3.js";import"./PhWebhooksLogo.vue.ca0fc489.js";import"./ant-design.b167c820.js";import"./index.81bff51e.js";import"./Modal.fb9d97fb.js";import"./Text.b0ae0f80.js";import"./Base.2cf6cca2.js";import"./index.38a388d2.js";import"./index.72e9756f.js";import"./index.feda5b51.js";import"./Paragraph.0762ff9a.js";import"./index.1893243b.js";import"./Link.58a56401.js";import"./Title.8356c432.js";import"./index.79c263e0.js";import"./CollapsePanel.5f9312a1.js";import"./index.cead1e00.js";import"./index.5920a48d.js";import"./isNumeric.75337b1e.js";import"./PhArrowCounterClockwise.vue.01cffaf3.js";import"./LoadingOutlined.7dd20886.js";import"./index.971fc0f1.js";import"./Form.c8ea7c3d.js";import"./hasIn.c05f2ad3.js";import"./string.08374cff.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="7acdbfcf-1e88-4c6c-894f-1cb61c858d48",e._sentryDebugIdIdentifier="sentry-dbid-7acdbfcf-1e88-4c6c-894f-1cb61c858d48")}catch{}})();const K={class:"threads-view"},x=f({__name:"Threads",setup(e){const a=new T(d),i=new y(w,"kanban-selected-stages"),o=l("kanban");return(I,s)=>(r(),_("div",K,[n(t(h),{activeKey:o.value,"onUpdate:activeKey":s[0]||(s[0]=b=>o.value=b)},{default:u(()=>[n(t(c),{key:"kanban",tab:"Kanban View"}),n(t(c),{key:"table",tab:"Table View"})]),_:1},8,["activeKey"]),o.value==="kanban"?(r(),p(g,{key:0,"kanban-repository":t(a),"kanban-stages-storage":t(i)},null,8,["kanban-repository","kanban-stages-storage"])):m("",!0),o.value==="table"?(r(),p(v,{key:1,"kanban-repository":t(a)},null,8,["kanban-repository"])):m("",!0)]))}});const ut=k(x,[["__scopeId","data-v-a5896313"]]);export{ut as default};
//# sourceMappingURL=Threads.faed47cd.js.map
