import{g as h}from"./api.47f2b83e.js";import{a as k}from"./asyncComputed.1c2e733f.js";import{F as w}from"./PhArrowSquareOut.vue.42aab9d1.js";import{d as v,eK as x,J as C,b as t,ew as u,u as e,c as i,w as r,ex as F,bh as I,as as f,aE as D,eF as H,f as c,eH as T,x as z}from"./outputWidgets.f4ff73cb.js";import"./index.1893243b.js";import"./index.f5809359.js";import{A as _}from"./index.38a388d2.js";import{a as y}from"./Base.2cf6cca2.js";import{C as B}from"./Card.c86b7818.js";import"./index.d3c08eba.js";import"./fetch.94c8b741.js";import"./pubsub.f8e50115.js";import"./runnerData.f9578373.js";import"./url.f4aa4fed.js";import"./Link.58a56401.js";import"./Paragraph.0762ff9a.js";import"./Text.b0ae0f80.js";import"./Title.8356c432.js";import"./TabPane.12230f18.js";import"./hasIn.c05f2ad3.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[s]="600dd6aa-44e1-4120-8464-e091c83a72f6",a._sentryDebugIdIdentifier="sentry-dbid-600dd6aa-44e1-4120-8464-e091c83a72f6")}catch{}})();const E=v({__name:"Home",setup(a){const s=x(),{result:p,loading:g}=k(h),m=C(()=>{var o,l;return(l=(o=p.value)==null?void 0:o.sidebar.filter(n=>n.visible))!=null?l:[]}),b=o=>{s.push({path:`/${o}`})};return(o,l)=>{var n;return t(),u("div",{class:"container",style:F({backgroundColor:(n=e(p))==null?void 0:n.theme})},[e(g)?(t(),i(e(I),{key:0})):m.value.length===0?(t(),i(e(y),{key:1,type:"secondary",style:{"font-size":"18px"}},{default:r(()=>[f(" There are no public forms available ")]),_:1})):(t(),i(e(_),{key:2,vertical:"",gap:"large",style:{padding:"120px 0"}},{default:r(()=>[(t(!0),u(D,null,H(m.value,d=>(t(),i(e(B),{key:d.id,class:"form-card",onClick:S=>b(d.path)},{default:r(()=>[c(e(_),{gap:"large",align:"center",justify:"space-between"},{default:r(()=>[c(e(y),{style:{"font-size":"18px","font-weight":"500"}},{default:r(()=>[f(T(d.name),1)]),_:2},1024),c(e(w),{color:"#000",width:"20"})]),_:2},1024)]),_:2},1032,["onClick"]))),128))]),_:1}))],4)}}});const ee=z(E,[["__scopeId","data-v-420f3514"]]);export{ee as default};
//# sourceMappingURL=Home.45153c02.js.map
