import{W as i}from"./outputWidgets.f4ff73cb.js";import{c,d}from"./index.e271d0b6.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="5ebf1471-ebb9-4346-8332-fbb6401ad1f3",e._sentryDebugIdIdentifier="sentry-dbid-5ebf1471-ebb9-4346-8332-fbb6401ad1f3")}catch{}})();const{DatePicker:n,WeekPicker:r,MonthPicker:t,YearPicker:f,TimePicker:b,QuarterPicker:o,RangePicker:a}=c(d),y=i(n,{WeekPicker:r,MonthPicker:t,YearPicker:f,RangePicker:a,TimePicker:b,QuarterPicker:o,install:e=>(e.component(n.name,n),e.component(a.name,a),e.component(t.name,t),e.component(r.name,r),e.component(o.name,o),e)});export{y as D,t as M,o as Q,a as R,r as W};
//# sourceMappingURL=dayjs.98bad7c2.js.map
