import{d,b as o,ew as s,f as a,u as r,bh as _,x as c}from"./outputWidgets.f4ff73cb.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="510ce54f-26e1-4448-98d4-6347717a7fd7",e._sentryDebugIdIdentifier="sentry-dbid-510ce54f-26e1-4448-98d4-6347717a7fd7")}catch{}})();const i={class:"centered"},f=d({__name:"LoadingContainer",setup(e){return(n,t)=>(o(),s("div",i,[a(r(_))]))}});const u=c(f,[["__scopeId","data-v-1da18eee"]]);export{u as L};
//# sourceMappingURL=LoadingContainer.b1642792.js.map
