import{d as l,eE as _,eK as p,b as u,ew as m,f as i,w as s,u as a,c as y,ey as g,as as n,eH as c,bG as b,x as h}from"./outputWidgets.f4ff73cb.js";import{A as w}from"./Title.8356c432.js";import{a as k}from"./Base.2cf6cca2.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new x().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="0c66b1eb-d348-4371-9fdf-25d5bfe443d1",e._sentryDebugIdIdentifier="sentry-dbid-0c66b1eb-d348-4371-9fdf-25d5bfe443d1")}catch{}})();const I={class:"inner-content"},v=l({__name:"Error",setup(e){const t=_(),d=p(),o=()=>{const{status:r}=t.params;switch(r){case"404":return{status:r,title:"Page not found",message:"We couldn't find the page you were looking for."};case"403":return{status:r,title:"Access denied",message:"You tried to access a page you did not have prior authorization for. Please contact your administrator.",action:"Go back to home"};default:return{status:"500",title:"Internal server error",message:"An unknown error ocurred. Please try again or contact support."}}},f=()=>{d.push({name:"playerHome"})};return(r,D)=>(u(),m("div",I,[i(a(w),null,{default:s(()=>[n(c(o().title),1)]),_:1}),i(a(k),{class:"message"},{default:s(()=>[n(c(o().message),1)]),_:1}),o().action?(u(),y(a(b),{key:0,type:"primary",onClick:f},{default:s(()=>[n(c(o().action),1)]),_:1})):g("",!0)]))}});const x=h(v,[["__scopeId","data-v-f770b2d7"]]);export{x as default};
//# sourceMappingURL=Error.4046b1fc.js.map
