import{P as y}from"./PlayerNavbar.f039b331.js";import{g as v}from"./api.47f2b83e.js";import{u as o}from"./index.d3c08eba.js";import{d as h,eK as w,r as k,K as I,a as L,b as n,ew as r,f as i,u as c,x}from"./outputWidgets.f4ff73cb.js";import{a as d}from"./asyncComputed.1c2e733f.js";import{L as D}from"./CircularLoading.2e718102.js";import"./PhKanban.vue.12e8939b.js";import"./PhSignOut.vue.21b85b35.js";import"./index.db4b3bef.js";import"./Text.b0ae0f80.js";import"./Base.2cf6cca2.js";import"./runnerData.f9578373.js";import"./url.f4aa4fed.js";import"./fetch.94c8b741.js";import"./pubsub.f8e50115.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="3fed844e-c13b-4a33-829a-05ef874e4392",e._sentryDebugIdIdentifier="sentry-dbid-3fed844e-c13b-4a33-829a-05ef874e4392")}catch{}})();const K={class:"main-container"},M={key:0,class:"centered"},C={key:1,class:"content"},E=h({__name:"Main",setup(e){const a=w(),s=k(o.getUser());o.pubsub.subscribe("authenticated",t=>{s.value=t});const{result:p,refetch:m}=d(async()=>(await o.allow("kanban")).status==="ALLOWED");I(s,()=>m());const l=({path:t})=>{a.push({name:"form",params:{path:t.split("/")}})},{result:_,loading:f}=d(v),b=()=>{o.removeUser(),a.push({name:"playerHome"})};return(t,N)=>{var u;const g=L("router-view");return n(),r("div",K,[i(y,{"runner-data":c(_),"is-kanban-visible":c(p)||!1,"user-email":(u=s.value)==null?void 0:u.claims.email,onNavigate:l,onLogout:b},null,8,["runner-data","is-kanban-visible","user-email"]),c(f)?(n(),r("div",M,[i(D)])):(n(),r("section",C,[i(g)]))])}}});const Q=x(E,[["__scopeId","data-v-020a5948"]]);export{Q as default};
//# sourceMappingURL=Main.3b24a134.js.map
