import{e_ as n,e$ as t}from"./outputWidgets.f4ff73cb.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},f=new Error().stack;f&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[f]="a1526209-2f0d-4522-9f0a-7b50e0325f2f",e._sentryDebugIdIdentifier="sentry-dbid-a1526209-2f0d-4522-9f0a-7b50e0325f2f")}catch{}})();function d(e,f){return n(1,arguments),t(e,Date.now(),f)}export{d as f};
//# sourceMappingURL=index.feda5b51.js.map
