import{g as m}from"./api.47f2b83e.js";import{u as p}from"./index.d3c08eba.js";import{d,eK as f,eE as u,b as i,ew as _,u as a,c as l,w as y,ey as g,f as b,x as h}from"./outputWidgets.f4ff73cb.js";import{_ as w}from"./Login.vue_vue_type_script_setup_true_lang.ef7fc0e0.js";import{a as k}from"./asyncComputed.1c2e733f.js";import{W as v}from"./WidgetsFrame.d26e64d1.js";import"./runnerData.f9578373.js";import"./url.f4aa4fed.js";import"./fetch.94c8b741.js";import"./pubsub.f8e50115.js";import"./Link.58a56401.js";import"./Base.2cf6cca2.js";import"./index.efd7a444.js";import"./PhArrowClockwise.vue.389e5739.js";import"./CircularLoading.2e718102.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="ec3fe7ae-9d69-44be-978b-c6e88a7ac544",e._sentryDebugIdIdentifier="sentry-dbid-ec3fe7ae-9d69-44be-978b-c6e88a7ac544")}catch{}})();const x={class:"login"},I=d({__name:"Login",setup(e){const t=f(),r=u(),{result:o}=k(m),c=async()=>{await p.signUp();const{redirect:s,...n}=r.query;if(s){t.push({path:s,query:n,params:r.params});return}t.push({name:"playerThreads",query:n})};return(s,n)=>(i(),_("div",x,[a(o)?(i(),l(v,{key:0,"main-color":a(o).mainColor,theme:a(o).theme,"font-family":a(o).fontFamily,style:{width:"100vw"}},{default:y(()=>[b(w,{onDone:c})]),_:1},8,["main-color","theme","font-family"])):g("",!0)]))}});const $=h(I,[["__scopeId","data-v-eac71f44"]]);export{$ as default};
//# sourceMappingURL=Login.10940c0f.js.map
